% function out = knn_new(name)
%
% Creates a new Artificial Neural Network (ANN) model
%
% Inputs:
%   name: string containing a name for the model (optional)
%
% Outputs:
%   out: the model
function out = ann_new(name)

if exist('name', 'var')
    name = 'Neural Network Model';
end;
out = model_new(name);

%%%
% General fields
out.important_prop_names = {'time_train', 'time_estimate'};
out.important_prop_descriptions = {'Training time (seconds)', 'Testing time (seconds)'};
if exist('name', 'var')
    out.name = name;
end;

out.f_train = 'ann_train'; % function that will train the model
out.f_test = 'ann_estimate'; % function that will train the model
out.f_boot = 'ann_boot'; % function that will boot the model. Usually not changed.

% whether classes must be converter into multiple-output boolean targets.
% This is the default in ANN models because it has been proven to be
% better.
out.flag_class2mo = 1; 

out.hiddens = [1]; % Number of neurons in each hidden layer.

% Learning parameters. Names match the ondes in net.trainParam
out.goal = 0.01;
out.epochs = 100;
out.show = 10;
out.lr = 0.05;
out.max_fail = 6;


% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
