% function draw_MARKER_MARKERS(results, flag_wntext)
function bmresults_draw_markers(results, flag_wntext)

if ~exist('flag_wntext')
    flag_wntext = 0;
end;

MARKER_MAXSIZE = 35;
MARKER_MINSIZE = 8;

% MARKER_MARKERS = '^spo<h';
MARKER_MARKERS = 'do^v<>ph';
MARKER_COLORS = colors3();

no_datasets = length(results.items);

wn1 = min(results.x);
wn2 = max(results.x);


hh = [];
hout = [];
legends = {};

xlim = [floor(round(wn1/50)*50/100)*100, ceil(round(wn2/50)*50/100)*100];

% Draw the vertical lines which will help identify the wavenumbers
if 1
    for x = ceil(wn1/50)*50:50:floor(wn2/50)*50
        
        % vertical line cannot overlap the "natural" matlab tick
        if x/200 == floor(x/200)
            uf = 0.17/8*no_datasets;
        else
            uf = 0.02/8*no_datasets;
        end;
        
        plot([x, x], [uf, no_datasets+1-uf], '--', 'LineWidth', 2, 'Color', .7*[1, 1, 1]);
        hold on;
    end;
end;



for i_dataset = 1:no_datasets
    height = i_dataset;

    result = results.items(i_dataset);
    
    plot(xlim, height*[1, 1], 'k', 'LineWidth', 3);
    hold on;
    hh(end+1) = text(xlim(2)+5, height, result.name, 'HorizontalAlignment', 'right');
        

        
    for i_line = 1:length(result.lines)
        line = result.lines(i_line);
        if ~isempty(line.y)
            y = line.y(line.peak_idxs);
            x = result.x(line.peak_idxs);
            no_markers = length(x);
            
            if max(y) ~= min(y)
                markersizes = (y-min(y))/(max(y)-min(y))*(MARKER_MAXSIZE-MARKER_MINSIZE)+MARKER_MINSIZE;
            else
                markersizes = ones(1, no_markers)*MARKER_MAXSIZE;
            end;
                
      
            for i_marker = 1:no_markers
                htemp = plot(x(i_marker), height, 'LineStyle', 'none', 'Marker', MARKER_MARKERS(i_line), 'Color', MARKER_COLORS{i_line}, ...
                    'MarkerSize', markersizes(i_marker), 'LineWidth', 4); %, 'MarkerFaceColor', 'w');

                if i_dataset == 1 && i_marker == 1
                    hout(end+1) = htemp; % for legends later
                    legends{end+1} = results.legends{i_line};
                end;

                if flag_wntext
                    text(x(i_marker), height-.1, sprintf('%4.0f', x(i_marker)));
                end;
            end;
        end;
    end;        
end;

set(gca, 'XTick', ceil(wn1/100)*100:200:ceil(wn2/100)*100);
set(gca, 'XLim', xlim);
% set(gca, 'XGrid', 'on');
% set(gca, 'XMinorGrid', 'on');
% set(gca, 'XMinorTick', 'on');


set(gca, 'YTick', []); %1:no_datasets);
% set(gca, 'YTickLabel', []);
set(gca, 'YLim', [0, no_datasets+1]);
set(gca, 'XDir', 'reverse');
set(gca, 'YDir', 'reverse');


legend(hout, legends);
format_frank(gcf, 1, hh);
resize_legend_markers(15);




% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
