% function cc = calc_confusion(classes_row, classes_col, flag_percentage)
%
% Inputs:
%   flag_percentage: whether to divide each row by its sum
% Outputs:
%   cc: confusion matrix
function cc = calc_confusion(classes_row, classes_col, flag_percentage, no1, no2)

if ~exist('flag_percentage', 'var')
    flag_percentage = 0;
end;

if ~exist('no1', 'var')
    no1 = max(classes_row)+1;
end;
if ~exist('no2', 'var')
    no2 = max(classes_col)+1;
end;

cc = zeros(no1, no2);

for i = 1:length(classes_row)
    idx1 = classes_row(i)+1;
    idx2 = classes_col(i)+1;
    cc(idx1, idx2) = cc(idx1, idx2)+1;
end;


if flag_percentage
    for i = 1:no1
        s = sum(cc(i, :));
        if s > 0
            cc(i, :) = cc(i, :)/s;
        end;
    end;
end;

    
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
