% function values = calc_predictive_values(cc)
%
% Inputs:
%   cc: confusion matrix in HITS, NOT PERCENTAGE
%
% Outputs:
%   values: predictive values for each column of cc
%
%    P(a|A) = P(A|a)*P(a)/P(A)
%    however this formula is not used, because it is easier to use a column
%    of the confusion matrix
%
% P(a|A) is the probability of belonging to
% class 'a' given that you have been classified as so.
%
function values = calc_predictive_values(cc)


no_classes = size(cc, 2);

values = zeros(1, no_classes);

for i = 1:no_classes
    
    % P(a|A) = P(A|a)*P(a)/P(A)
    %
    % P(A|a) = n_aA/n_a
    % P(a) = n_a/n
    % P(A) = n_A/n
    %
    % The formula simplifies to 
    % P(a|A) = n_aA/n_A
    values(i) = cc(i, i)/sum(cc(:, i));
end;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
