% function [A, B] = cca(X, Y, P)
%
% P: either the penalty coefficients of a penalty matrix itself
function [A, B] = cca(X, Y, P)

[no, nf] = size(X);

if ~exist('P', 'var')
    P = 0;
else
    [q, w] = size(P);
    if q ~= nf || w ~= nf
        % assumes the coefficients have been passed
        P = no*penalty_matrix(nf, P);
    else
    end;
end;


Y = data_normalize(Y, 's');
X = data_normalize(X, 's'); % We need this otherwise the correlation X'*Y needs normalization


if 1
    [A, B] = canoncorr(X, Y);
else
    % Hastie et. al. 2001, The elements of statistical learning, exercise
    % 3.18.
    
    % This algorithm is working fine
    
    p = min(size(X, 2), size(Y, 2))-1;
    
    M = (Y'*Y)^(-1/2)*(Y'*X)*(X'*X+P)^(-1/2);
    [U, D, V] = svd(M);
    
    B = (Y'*Y)^(-1/2)*U(:, 1:p);
    A = (X'*X+P)^(-1/2)*V(:, 1:p);
 end;
    

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
