% Produces class loadings as in JCB2007.PDF
% 
% CL = class_loadings(data, loadings, lambdas)
%
% data: structure containing data already transformed by loadings
% loadings: transformation matrix, usually containing eigenvectors as columns.
%    This applies to PCA or LDA.
%
% lambdas (optional): eigenvalues corresponding to each column of loadings. 
%                     if not provided, a vector or ones will be assumed
%
% CL(:, k) = loadings*(m_k.*lambdas), where
% m_k is the center of the k-th population of the data

function CL = class_loadings(data, loadings, lambdas)

% no_features1 was the number of features before the loadings-transform
% no_features2 is the number of features after the loadings-transform (must equal 
%              the number of columns of data.X).
[no_features1, no_features2] = size(loadings);

if ~exist('lambdas')
    lambdas = ones(no_fetures2, 1);
end;

pieces = data_split_classes(data);
no_classes = length(pieces);

CL = zeros(no_features1, no_classes);

for k = 1:no_classes
    m = mean(pieces(k).X, 1)'; % mean vector: averages each column of dataset for class k (the transpose makes it a column vector)
    CL(:, k) = loadings*(m.*lambdas);
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
