% output = classes2boolean(classes, no_different)
%
% classes: Zero-based class vector. It may be a column or row vector, doesn't matter. 
%
% output: matrix described below.
%
% Converts classes into a boolean matrix where each column correspond to
% one class. It will contain a one in column j if the i-th row belongs to
% the j-th class or zero otherwhise.
function output = classes2boolean(classes, no_different)

if ~exist('no_different', 'var')
    no_different = max(classes)+1; % number of classes
end;
len = length(classes);
output = zeros(len, no_different);

for i = 1:len
    for j = 1:no_different
        if j-1 == classes(i)
            output(i, j) = 1;
        else
            output(i, j) = 0;
        end
    end
end

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
