% [valid, no_right] = classify_knn(k, train, valid)
%
% k-NN algorithm. Returns:
%
% valid: same as input, but classes are assigned to 'valid.classes' as
%        result of the algorithm's decisions.
function valid = classify_knn(k, train, valid)


max_class = max(train.classes);
min_class = min(train.classes);
class_no = max_class-min_class+1;
votes = zeros(class_no, 2);

no_valid = size(valid.X, 1);
no_train = size(train.X, 1);


for i = 1:no_valid
    % vector to be tested
    v_test = valid.X(i, :);

    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % Mounts a distance vector with a second column which is the class

    
    % computes a vector of squared distances
    dists = [zeros(no_train, 1) train.classes];    % puts classes on right column for further sort
    for j = 1:no_train
        v_temp = train.X(j, :)-v_test; % row vector
        dists(j, 1) = v_temp*v_temp';
    end;

    dists = sortrows(dists);
    
    % inits votes matrix. Each column is (number_of_votes, class)
    votes(:, 1) = 0;
    votes(:, 2) = min_class:max_class;
    
    for j = 1:min(no_train, k)
        votes(dists(j, 2)-min_class+1, 1) = votes(dists(j, 2)-min_class+1, 1)+1;  % Here a weight on the vote can be put 
    end;

    votes = sortrows(votes);
    decision = votes(class_no, 2); % The pool is in ascending order, so takes last one

    valid.classes(i) = decision;
end;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
