% data = data_average_by_colony(data)
%
% Spectra are averaged. Grouping is done using data.colony_codes.
%
% Should 2 spectra in the same colony have different classes, the assumed 
% is the one assigned to the
% first spectra in the colony.
function data = data_average_by_colony(data)

if length(data.classes) ~= length(data.colony_codes)
    error('Dataset cannot be averaged because .colony_codes is invalid!');
end;

flag_idcolony_s = ~isempty(data.idcolony_s);

[no_obs, no_fea] = size(data.X);

X_new = zeros(1, no_fea);
if flag_idcolony_s
    idcolony_s_new = zeros(1, 1);
end;
colony_codes_new = {};
idspectrum_s = [];
classes_new = zeros(1, 1);
file_names_new = {};
step = 1;

colony_code_old = '';
average_count = 0;
i = 1;
while 1
    flag_break = i > no_obs;
    flag_record_average = 0; % Will an average be recorded in this loop passs?
    
    if flag_break
        flag_record_average = 1;
    else
        colony_code = data.colony_codes{i};
        if ~strcmp(colony_code, colony_code_old)
            flag_record_average = 1;
        end;
    end;
    
    % colony_code has changed?
    if flag_record_average
        
        % Hasn't it changed because it is first time in the loop?
        if ~isempty(colony_code_old)
            average_count = average_count+1;

            fprintf('%2d observations from colony_code ''%s''\n', spectrum_count, colony_code_old);
            
            % Efficient way to increase matrix sizes (at the end the unused
            % allocated space will be truncated).
            if average_count > step
                step = step*2;
%                 fprintf('Step now!!!! %d\n', step);
                if flag_idcolony_s
                    idcolony_s_new(step, 1) = 0;
                end;
                colony_codes_new{step, 1} = '';
                file_names_new{step, 1} = '';
                classes_new(step, 1) = 0;
                X_new(step, :) = zeros(1, no_fea);
            end;
            
            if flag_idcolony_s
                idcolony_s_new(average_count) = idcolony_old;
            end;
            colony_codes_new{average_count} = colony_code_old;
            file_names_new{average_count} = file_name_old;
            classes_new(average_count) = class_old;
            X_new(average_count, :) = spectrum_sum/spectrum_count;
            idspectrum_s(average_count, 1) = spectrum_count;
        end;
        
        if ~flag_break
            % Initialization for new colony
            spectrum_count = 0;
            spectrum_sum = zeros(1, no_fea);
            colony_code_old = colony_code;
            if flag_idcolony_s
                idcolony_old = data.idcolony_s(i);
            end;
            class_old = data.classes(i);
            file_name_old = data.file_names{i};
        end;
    end;
    
    if flag_break
        break;
    end;
    
    spectrum_sum = spectrum_sum+data.X(i, :);
    spectrum_count = spectrum_count+1;
    i = i+1;
end;
        
     
fprintf('asdasds');
data.X = X_new(1:average_count, :);
if flag_idcolony_s
    data.idcolony_s = idcolony_s_new(1:average_count, :);
else
    data.idcolony_s = {};
end;
data.idspectrum_s = idspectrum_s(1:average_count);
data.colony_codes = colony_codes_new(1:average_count);
data.classes = classes_new(1:average_count, :);
data.file_names = file_names_new(1:average_count);

fprintf('INFO (data_average_by_colony()): Spectra were averaged. # of spectra before: %d; # of average spectra: %d.\n', no_obs, average_count);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
