% o.hist_space, o.cc, o.xx, o.mm, o.yy
% function o = data_calculate_3dhist(dataa, THRESHOLD, hist_no_divisions)
%
% percentages below THRESHOLD will be considered zero for decision purposes inside the function
function o = data_calculate_3dhist(dataa, THRESHOLD, hist_no_divisions)

if ~exist('THRESHOLD', 'var')
    THRESHOLD = 0.001; % 
end;

if ~exist('hist_no_divisions', 'var')
    hist_no_divisions = 100;
end;

no_dataa = length(dataa);
data = data_merge(dataa);

no_features = size(data.X, 2);
min_data = min(min(data.X));
max_data = max(max(data.X));


hist_space = linspace(min_data, max_data, hist_no_divisions);


mm = cell(1, no_dataa);
for i_m = 1:no_dataa
    mm{i_m} = zeros(hist_no_divisions, no_features);
    for i = 1:no_features
        mm{i_m}(:, i) = hist(dataa(i_m).X(:, i), hist_space);
    end;

    % Scaling between 0 and 1
    mm{i_m} = mm{i_m}/max(max(mm{i_m}))*100;


    % mm = [zeros(1, no_features); mm; zeros(1, no_features)];
    % mm = [zeros(size(mm, 1), 1) mm zeros(size(mm, 1), 1)];
end;

[xx, yy] = meshgrid(data.x, hist_space);
zz = zeros(hist_no_divisions, no_features);
cc = zeros(hist_no_divisions, no_features);

for i = 1:no_features
    for j = 1:hist_no_divisions
        v = zeros(no_dataa, 1);
        for k = 1:no_dataa
            v(k) = mm{k}(j, i);
        end;
        [val, ind] = max(v);
        if val < THRESHOLD
            cc(j, i) = 1;
            zz(j, i) = 0;
        else
%             fprintf('ind : %d; ', ind);
            cc(j, i) = ind+1;
            zz(j, i) = val;
        end;
    end;
end;

% 
% surf(xx, yy, mm, cc);
% format_wn(data);
% set(gca, 'YLim', [min_data, max_data]);
% zlabel('%');
% title('Surface of histograms');
% shading('interp');
% format_frank();

o.hist_space = hist_space;
o.mm = mm;
o.zz = zz;
o.xx = xx;
o.yy = yy;
o.cc = cc;
o.min_data = min_data;
o.max_data = max_data;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
