% function data = data_diff_sg(data, order, porder, ncoeff)
%
% Savitzky-Golay differentiation
%
%   order: differential order. Accepted values: 1 or 2
%   porder: polynomial order
%   ncoeff: number of filter coefficients. Must be off
%
function data = data_diff_sg(data, order, porder, ncoeff)

if ~exist('order', 'var')
    order = 1;
end;
if ~exist('porder', 'var')
    porder = 2;
end;
if ~exist('ncoeff', 'var')
    ncoeff = 9;
end;


if order ~= 1 && order ~= 2
    error('Accepted differential orders: 1 and 2 only!');
end;


if ncoeff/2 == floor(ncoeff/2)
    error('Number of filter coefficients must be odd!');
end;


offset = (ncoeff-1)/2;
[no, nf] = size(data.X);
j1 = 1+offset;
j2 = nf-offset;

Xout = zeros(no, nf-2*offset);
Xdo = data.X(:, 1+offset:nf-offset);



N = 2;                 % Order of polynomial fit
F = 9;                % Window length
[b,g] = sgolay(porder, ncoeff); % Calculate S-G coefficients

% dx = .2;
% xLim = 200;
% x = 0:dx:xLim-1;
% 
% y = 5*sin(0.4*pi*x)+randn(size(x));  % Sinusoid with noise


HalfWin  = ((F+1)/2) -1;
for i = 1:no
    temp = conv(Xdo(i, :), g(:, order));
    Xout(i, :) = temp(1+offset:end-offset);
end;
Xout = Xout*factorial(order);

data.X = Xout;
data.x = data.x(1+offset:nf-offset);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
