% varargout = data_eliminate_outliers_by_distance(data, diff_order, threshold, flag_interactive)
%
% Sorts spectra according to distance from the mean spectra
%
% If flag_interactive is on, a figure will be generated and the threshold
% will be asked
function varargout = data_eliminate_outliers_by_distance(data, threshold, diff_order, flag_interactive)


if ~exist('diff_order', 'var')
    diff_order = 2;
end;


[data, dists, indexes_original] = data_sort_distance(data, 'density'); % 1 stands for Mahalanobis distance

if diff_order > 0
    ddists = diff(dists, diff_order);
else
    ddists = dists;
end;

if flag_interactive
    figure;
    plot(ddists);
    threshold = input('Please see the figure and decide upon threshold: ');
end;


ddists(ddists < threshold) = 0; % Threshold because derivatives have small peaks everywhere
ddists(1:floor(length(ddists)/2-1)) = 0; % Kills first halp because of instabilities at the beginning

v = 1:length(ddists);
idxs_above = v(ddists >= threshold);

if ~isempty(idxs_above)
    idx_last = idxs_above(1)+diff_order-1;
    indexes_in = 1:idx_last;
    fprintf('Info: outliers removed: %d.\n', size(data.X, 1)-length(indexes_in));

else
    disp('Warning: sorry, could not find an outlier beginning, no outlier removed. plot(ddists) to have a look.');
    indexes_in = 1:size(data.X, 1);
end;

data = data_map_rows(data, indexes_in);
indexes_original = indexes_original(indexes_in);

% Gotta put spectra in a fair order again
[data, idxs] = data_sort_by_colony(data);
indexes_original = indexes_original(idxs);



if nargout == 1
    varargout = {data};
else
    varargout = {data, indexes_original};
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
