% new = data_eliminate_var_0(data, threshold = 1e-10)
%
% Eliminates features with variance below a threshold. This helps making
% the covariance matrix of the data non-singular.
%
% Works on data.X and data.x simultaneously.
function data = data_eliminate_var_0(data, threshold)

if nargin() == 1
    threshold = 1e-10;
end;

v = var(data.X);

no_fea = size(data.X, 2);
no = sum(v <= threshold);

if no > 0
    X_new = [];
    x_new = [];
    for i = 1:size(data.X, 2)
        if v(i) > threshold
            X_new = [X_new data.X(:, i)];
            x_new = [x_new data.x(:, i)];
        end;
    end;
    
    data.X = X_new;
    data.x = x_new;
else
    %
end;

fprintf('INFO: Features with variance <= %g were eliminated: %d - %d = %d .\n', threshold, no_fea, no, no_fea-no);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
