% function d = data_loadings_combo(dataa)
%
% This function creates a new dataset as follows:
% - d starts equal to dataa(end).
% - d.L will be the multiplication of the L's of all dataa(i)
% - previous information, such as .previous_domain, will be retrieved from dataa(1)
%
% Assumptions are made:
% - inner dimmensions of dataa(i).L are compatible
% - dataa(1), dataa(2) etc have actually been generated in cascade.
%
% This function is suitable for generating PCA-LDA-transformed datasets, or
% recently the BSpline-LDA technique.
%
% The main point is getting loadings whose indexes are in the original
% domain (the previous domain of dataa(1))
function d = data_loadings_combo(dataa)

noa = length(dataa);

L = 1;
s_domain = '';
for i = 1:noa
    if i > 1 && size(L, 2) ~= size(dataa(i).L, 1)
        error('Disagreement in inner dimensions of loadings metrices: %d vs. %d !', size(L, 2), size(dataa(i).L, 1));
    end;
    
    L = L*dataa(i).L;
    s_domain = [s_domain dataa(i).domain];
end;

d0 = dataa(1);
d = dataa(end);

d.L = L;
d.domain = s_domain;

d.previous_domain = d0.previous_domain;
d.previous_flag_wn = d0.previous_flag_wn;
d.previous_x = d0.previous_x;


% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
