% Loads spectra and classification from database
%
% Makes up a 'data' structure with
%   - X: data matrix (rows are spectra, columns are wavenumbers)
%   - classes: classification index (0, 1, 2 and so on), one for each row in data.
%   - idspectrum_s: a column vector containing the same number of row as
%     data. Its elements are the spectrum id corresponding to each row
%     in data
%   - no_wavenumbers: matches number of columns in data.X but comes from a
%     different source
%   - class_labels: legends for each class
%   - idjudge_ref: db:judge.id
%
%   params: .idexperiment, .iddomain, .idjudge, .iddeact
function data = data_new_from_database(session)


disp('-- Doing the BIG select ... --')

s_joins = [' LEFT JOIN series ON series.idspectrum = spectrum.id and series.iddomain = ' mat2str(session.iddomain) ' LEFT JOIN deact_spectrum ON  deact_spectrum.idspectrum = spectrum.id and deact_spectrum.iddeact = ' mat2str(session.iddeact) ...
    ' LEFT JOIN colony ON colony.id = spectrum.idcolony'];

s_fields = ['spectrum.id, spectrum.file_name, colony.id, colony.code, (flag_inactive is null or flag_inactive = 0) as flag_active, series.vector, series.id'];
s_outputs = ['idspectrum, file_name, colony_id, colony_code, flag_active, vector, series_id'];
s_outputs_params = [];
s_wheres = [' WHERE spectrum.idexperiment = ' mat2str(session.idexperiment) ' AND (flag_inactive is null or flag_inactive = 0)'];
for i_judge = 1:length(session.idjudge)
    s_ij = mat2str(i_judge);
    s_fields = [s_fields ', sj' s_ij '.params as params' s_ij];
    s_joins = [s_joins ' LEFT JOIN spectrum_judge sj' s_ij ' on sj' s_ij '.idspectrum = spectrum.id and ' ...
               'sj' s_ij '.idjudge = ' mat2str(session.idjudge(i_judge))];
           
    s_outputs = [s_outputs ', params' s_ij];
           
    if ~isempty(s_outputs_params)
        s_outputs_params = [s_outputs_params ', '];
    end;
    s_outputs_params = [s_outputs_params 'params' s_ij];

end;

s_select = ['SELECT ' s_fields ' FROM spectrum ' s_joins s_wheres ' HAVING series.id > 0 ORDER BY spectrum.idcolony, spectrum.id'];
% disp('quero.....ve..................................');
% keyboard;
disp(s_select);
    eval(['[' s_outputs '] = mym(''' s_select ''');']);
params_s = eval(['{' s_outputs_params '}']);


% disp('foiiiiiiiiii.......................................');
% keyboard;

disp('-- ... done --')


%%

no_obs = length(idspectrum);
no_wn = mym(['select wncount from domain where id = ' mat2str(session.iddomain)]);
no_judges = length(params_s);

data = data_new();
data.class_labels = {};
data.X = zeros(no_obs, no_wn);
data.classes = zeros(no_obs, 1);
data.idspectrum_s = idspectrum;
data.file_names = file_name;
data.idcolony_s = colony_id;
data.colony_codes = colony_code;

n = 1; % pointer over data
nn = 0;

cnt_ok = 0;

for i_obs = 1:no_obs
    
    vchar = char(vector{i_obs})';
    if length(vchar) > 0
    
        %--- resolves X
        try
            data.X(i_obs, :) = eval(vchar);
        catch ME
            disp('a');
        end;

        %--- resolves class
        %       . mounts a code like "A|T"
        code = '';
        virg = '';
        for i_judge = 1:no_judges
            if i_judge == 2
                virg = '|';
            end;
            code = [code virg strip_code(char(params_s{i_judge}{i_obs})')];
        end;

        %       . fits code in the dataset
        find_indexes = find(strcmp(data.class_labels, code));
        if isempty(find_indexes)
            data.class_labels{end+1} = code;
            data.classes(i_obs) = length(data.class_labels)-1;
        else
            data.classes(i_obs) = find_indexes(1)-1;
        end

        % progress visual feedback
        nn = nn+1;
        if nn == 199 % arbitrary value
            disp(sprintf('-- %5.1f %% --', i_obs/no_obs*100))
            nn = 0;
        end
        
        cnt_ok = cnt_ok+1;
    end;
end

data = data_sort_class_labels(data);

fprintf('%d spectra were read\n', cnt_ok);

    

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
