% data_plot_scatter_2d(data, idx_fea, confidences = [], flag_text=0)
%
% Inputs:
%   data: data structure
%   idx_fea: what features to use. Numbers correpond to columns in data.X
%   confidences: a list of percentages (]0, 1[) for the confidence ellipses
%   flag_text: whether to write the colony codes close to the markers
%
function data_plot_scatter_2d(data, idx_fea, confidences, flag_text)

if ~exist('confidences', 'var')
    confidences = [];
end;


if ~exist('flag_text', 'var')
    flag_text = 0;
end;

pieces = data_split_classes(data);
no_classes = size(pieces, 2);
no_fea = length(idx_fea);

i_count = 1;
for ix = 1:no_fea-1
    for iy = ix+1:no_fea
        if no_fea > 2
            subplot(no_fea-1, no_fea-1, (iy-2)*(no_fea-1)+ix);
        end;

        ihandle = 1;
        for i = 1:no_classes
            X = pieces(i).X(:, idx_fea([ix iy]));

            hh = plot(X(:, 1), X(:, 2), 'Color', find_color(i), 'Marker', find_marker(i), 'MarkerFaceColor', find_color(i), 'LineStyle', 'none');
            if ~isempty(hh)
                handles(ihandle) = hh(1);
                ihandle = ihandle+1;
            end;
            hold on;
            
            
            if flag_text
                text(X(:, 1), X(:, 2), pieces(i).colony_codes); %, 'FontName', FONT, 'FontSize', FONTSIZE*.7);
            end;

            % ellipses
            if ~isempty(confidences)
                m = mean(X);
                C = cov(X);
                for j = 1:length(confidences)
                    error_ellipse(C, m, 'conf', confidences(j), 'style', find_color(i));
                end;
            end;
        end
        
        feanames = data_get_feature_names(data, [idx_fea(ix) idx_fea(iy)]);
%         if iy == no_fea 
        if iy == ix+1
%             xlabel(feanames{1});
            title(feanames{1});
        end;
        if ix == 1
            ylabel(feanames{2});
        end;
        if i_count == 1
            legend(handles, data_get_legend(data));
        end;
        if iy < no_fea % || 1
            set(gca, 'XTick', []);
        end;
        if ix > 1 % || 1
            set(gca, 'YTick', []);
        end;
        i_count = i_count+1;
        format_frank();
        
    end;
end;

% feanames = data_get_feature_names(data, [idx_fea(ix) idxfea(iy)]);
% xlabel(feanames{1});
% ylabel(feanames{2});

% legend(handles, data.class_labels);
% title(sprintf('%s 2D Scatter Plot', data_get_title(data)));
% format_frank();
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
