% function varargout = data_plot_scatter_3d(data, idx_fea, confidences=[], flag_text=0)
%
% Inputs:
%   data: data structure
%   idx_fea: what features to use. Numbers correpond to columns in data.X
%   confidences: a list of percentages (]0, 1[) for the confidence ellipses
%   flag_text: whether to write the colony codes close to the markers
%
% Outputs:
%   [data]
%   [data, handles]
%
%   handles: handles for the legends
function varargout = data_plot_scatter_3d(data, idx_fea, confidences, flag_text)
global FONT FONTSIZE;


if ~exist('confidences', 'var')
    confidences = [];
end;

if ~exist('flag_text', 'var')
    flag_text = 0;
end;



pieces = data_split_classes(data);

no_classes = size(pieces, 2);
for i = 1:no_classes
    X = pieces(i).X(:, idx_fea([1 2 3]));
    
    hh = plot3(X(:, 1), X(:, 2), X(:, 3), 'Color', find_color(i), 'Marker', find_marker(i), 'MarkerSize', find_marker_size(i), 'MarkerFaceColor', find_color(i), 'LineStyle', 'none');
    handles(i) = hh(1);
    hold on;
    
    if flag_text
        text(X(:, 1), X(:, 2), X(:, 3), pieces(i).colony_codes); %, 'FontName', FONT, 'FontSize', FONTSIZE*.7);
    end;
    
    
    
    % ellipses
    if ~isempty(confidences)
        m = mean(X);
        C = cov(X);
        for j = 1:length(confidences)
            error_ellipse(C, m, 'conf', confidences(j), 'style', find_color(i));
        end;
    end;
end


feanames = data_get_feature_names(data, idx_fea);
xlabel(feanames{1});
ylabel(feanames{2});
zlabel(feanames{3});

legend(handles, data_get_legend(data));
title(sprintf('%s 3D Scatter Plot', data_get_title(data)));
format_frank();

if nargout <= 1
    varargout = {data};
elseif nargout == 2
    varargout = {data, handles};
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
