% function varargout = data_plot_scatter_3d(data, idx_fea, confidences)
%
% Inputs:
%   data: data structure
%   idx_fea: what features to use. Numbers correpond to columns in data.X
%
% Outputs:
%   [data]
%   [data, handles]
%
%   handles: handles for the legends
%   
function varargout = data_plot_scatter_3d2(data, idx_fea, confidences, flags_min)

if ~exist('confidences', 'var')
    confidences = [];
end;

if ~exist('flags_min', 'var')
    flags_min = [0, 0, 1];
end;

pieces = data_split_classes(data);

minmax = [min(data.X(:, idx_fea(1:3))); max(data.X(:, idx_fea(1:3)))];
xyz = [0, 0, 0];
k1 = 1.1;
k2 = 1.5;
for i = 1:3
    if flags_min(i)
        minmax(1, i) = minmax(1, i)*k2;
        minmax(2, i) = minmax(2, i)*k1;
        xyz(i) = minmax(1, i);
    else
        minmax(1, i) = minmax(1, i)*k1;
        minmax(2, i) = minmax(2, i)*k2;
        xyz(i) = minmax(2, i);
    end;
end;
        

no_classes = size(pieces, 2);
for i = 1:no_classes
    X = pieces(i).X(:, idx_fea([1 2 3]));
    
    hh = plot3(X(:, 1), X(:, 2), X(:, 3), 'Color', find_color(i), 'Marker', find_marker(i), 'MarkerSize', find_marker_size(i), 'MarkerFaceColor', find_color(i), 'LineStyle', 'none');
    handles(i) = hh(1);
    hold on;
    
    % ellipses
    if ~isempty(confidences)
        m = mean(X);
        C = cov(X);
        for j = 1:length(confidences)
            error_ellipse2(C, m, 'conf', confidences(j), 'style', find_color(i), 'xyz', xyz);
        end;
    end;
end


feanames = data_get_feature_names(data, idx_fea);
xlabel(feanames{1});
ylabel(feanames{2});
zlabel(feanames{3});

box off;
grid on;
% axis off;


data2 = [minmax; xyz];
perms = [1 2 3; 2 3 1; 3 1 2];
map = [1 2 2 1 1; 1 1 2 2 1; 3 3 3 3 3];
for i = 1:3
    xx = data2(map(perms(i, 1), :), 1);
    yy = data2(map(perms(i, 2), :), 2);
    zz = data2(map(perms(i, 3), :), 3);
    
    plot3(xx, yy, zz, 'k', 'LineWidth', 2);
end;
% plot3([xmin, xmax], [ymax, ymax], [zmin, zmin], 'k');
% plot3([xmax, xmax], [ymin, ymax], [zmin, zmin], 'k');
% plot3([xmax, xmax], [ymax, ymax], [zmin, zmax], 'k');

set(gca, 'XLim', minmax(:, 1)');
set(gca, 'YLim', minmax(:, 2)');
set(gca, 'ZLim', minmax(:, 3)');

legend(handles, data_get_legend(data));
title(sprintf('%s 3D Scatter Plot', data_get_title(data)));
format_frank();

if nargout <= 1
    varargout = {data};
elseif nargout == 2
    varargout = {data, handles};
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
