% [data_new, new_x] = data_select_features(data, v, v_type)
% Manual feature selection.
% v contains ranges or an index list (see v_type below) to include, 1 in each row.
%
% v_type: 'rx' if v is expressed in the same unit as data.x
%         'ri' if v contains index ranges
%         'i' if v contains feature indexes
% 
% Example:
% v = [1800, 1474; 1432, 1401; 1313, 1176; 1134, 900], if v_type == 'x'
% or
% v = [1 86;97 105;128 163;174 235], if v_type == 'i'
function data_new = data_select_features(data, v, v_type)

if ~exist('v_type', 'var')
    v_type = 'x';
end;

no_features = size(data.X, 2);

data_new = data;

if v_type == 'i'
    indexes = v;
elseif v_type == 'x'
    indexes = v_x2ind(v, data.x);
else
    if v_type == 'rx'
        ranges = v_x2ind(v, data.x);
    elseif v_type == 'ri'
        ranges = v;
    end;

    indexes = [];
    for i = 1:size(ranges, 1)
        indexes = [indexes  ranges(i, 1):ranges(i, 2)];
    end;
    
    data_new.ranges_wn = v;
    data_new.ranges_indexes = ranges;
end;

data_new.idx_fea = indexes;
data_new.X = data_new.X(:, indexes);
data_new.x = data_new.x(indexes);



if ~isempty(data_new.L)
    data_new.L = data_new.L(:, indexes);
end;

% % % % if strcmp(data_new.domain, 'pca')
% % % %     data_new.pca_idx_fea = indexes;
% % % %     data_new.V_star = data_new.V_star(:, indexes);
% % % % elseif strcmp(data_new.domain, 'lda') || strcmp(data_new.domain, 'pcalda')
% % % %     data_new.lda_idx_fea = indexes;
% % % %     data_new.W_star = data_new.W_star(:, indexes);
% % % % end;

% Corrects boundaries of background vectors
if ~isempty(data_new.background_x)
    ii = [indexes(1), indexes(end)];
    ww = [data_new.x(1), data_new.x(end)];
    iii = v_x2ind(ww, data_new.background_x);
    iiii = iii(1):iii(end);
    data_new.background_x = data_new.background_x(iiii);
    if ~isempty(data_new.background_y)
        data_new.background_y = data_new.background_y(iiii);
    end;
end;


fprintf('INFO (data_select_features()): # features before: %d; # features after: %d.\n', no_features, length(data_new.x));


% ranges = round(235-(v-900)/900*234);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
