% function data_select_features_paired_ttest(data, idx_reference=1)
function data = data_select_features_paired_ttest(data, idx_reference, type, param)


pieces = data_split_classes(data);
no_classes = length(pieces);
no_features = length(data.x);

R = zeros(no_classes-1, no_features);

ii = 0;
for i = 1:no_classes
    if i ~= idx_reference
        ii = ii+1;
        R(ii, :) = data_2classes_ttest(data_merge(pieces([idx_reference, i])));
    end;
end;


if type == 1
    % data may have many classes. The resulting yes/no significance of each variable is obtained by intersection,
    % i.e., pessimistic
    %
    significance = param;
    R = R > significance; % adjust the level of significance here

    idxs_fea = 1:no_features;
    idx_fea = idxs_fea(sum(R, 1) == 0);
else
    % For the fixed number of variables case, the p-values per wavenumber are averaged
    no_vars = param;
    r = mean(R, 1);
    [r_, idxs] = sort(r, 2, 'descend');
    idx_fea = sort(idxs(1:no_vars));
end;

data = data_select_features(data, idx_fea, 'i');
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
