% [data]
% [data, distances]
% [data, distances, indexes] = 
% data_sort_distance(data, mode, s2=mean wavenumber variance)
%
% sorts data in ascending order to mean spectrum
%
% Inputs:
%   - mode: 'euclidean', 'mahalanobis', 'density'
%
% Outputs:
%   - data: sorted dataset
%   - distances: distances from the mean spectrum in the sorted dataset
%   - indexes: indexes of the new spectra in respect to the old/unsorted dataset
function varargout = data_sort_distance(data, mode, s2)


means = mean(data.X, 1);
[no_obs, no_fea] = size(data.X);
    
Xcentered = data.X-meshgrid(means, ones(1, no_obs));

distances = zeros(no_obs, 1);

 
if strcmp(mode, 'density')
    if ~exist('s2')
        C = cov(Xcentered);
        s2 = trace(C)/no_fea;
    end;
    
    ii = 0;
    iii = 0;
    
    top = no_obs^2/2;

    for i = 1:no_obs
        xi = Xcentered(i, :)';
        for j = i:no_obs
            if i == j
                distances(i) = distances(i)+1;
            else
                xj = Xcentered(j, :)';

                d = 1/(1+(xi-xj)'*(xi-xj)/s2);
                distances(i) = distances(i)+d;
                distances(j) = distances(j)+d;
            end;

            ii = ii+1;
            iii = iii+1;
            if ii == 10000
                fprintf('density calc: %g%%...\n', iii/top*100);
                ii = 0;
            end;
        end;
    end;
    
else
    if mode == 'mahalanobis'
        Cinv = inv(cov(Xcentered));
    else
        Cinv = eye(no_fea, no_fea);
    end;


    for i = 1:no_obs
        v = Xcentered(i, :)';
        distances(i) = sqrt(v'*Cinv*v);
    end;
end;

shit = [(1:no_obs)' distances];
shit2 = sortrows(shit, 2);

idxnew = shit2(:, 1);
distancesnew = shit2(:, 2);

data = data_map_rows(data, idxnew);

if nargout == 3
    varargout = {data, distancesnew, idxnew};
elseif nargout == 2
    varargout = {data, distancesnew};
else
    varargout = {data};
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
