% pieces = data_split_classes(data)
% 
% Splits data according to classes. Returns an array of structures.
%
% data_split_classes separates data according to the class of each
% instance. Instances are the rows of 'data'.
%
% See also: data_new
function out = data_split_classes(data, hierarchy)

if ~exist('hierarchy', 'var')
    hierarchy = []; % means maximum possible
end;

no_obs = size(data.X, 1);
comoassim = class_labels2cell(data.class_labels, hierarchy);
idxs_cl_new = cell2mat(comoassim(:, 4));
no_classes = max(idxs_cl_new)+1;
classes_new = zeros(no_obs, 1);

% Fills a new class vector with numbers from new hierarchy
for i = 1:no_obs
    classes_new(i) = idxs_cl_new(data.classes(i)+1);
end;
    

% Mounts observation maps
map = cell(1, no_classes);
for i_index = 0:no_classes-1
    map{i_index+1} = find(classes_new == i_index);
end

% Applies observation maps
out = data_split_map(data, map);
    
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
