% function out = data_split_map(data, map)
%
% Splits data using row maps
%
% Inputs:
%   data: data structure, see data_new.m
%   map: cell array of row indexes
function out = data_split_map(data, map)

flag_idspectrum_s = isfield(data, 'idspectrum_s') && ~isempty(data.idspectrum_s);
flag_colony_codes = isfield(data, 'colony_codes') && ~isempty(data.colony_codes);
flag_ZZ = isfield(data, 'ZZ') && ~isempty(data.ZZ);

no_out = length(map);

for i = 1:no_out
    dnew = data;
    idxs = map{i};

    dnew.x = data.x;
    dnew.X = data.X(idxs, :);
    
    
%     dnew = data_update_background(dnew, data);

    

    if flag_idspectrum_s
        dnew.idspectrum_s = data.idspectrum_s(idxs);
        dnew.idcolony_s = data.idcolony_s(idxs);
        dnew.file_names = data.file_names(idxs);
    end;
    if flag_colony_codes
        dnew.colony_codes = data.colony_codes(idxs, :);
    end;
    if flag_ZZ
        dnew.ZZ = data.ZZ(idxs, :);
    end;


    
    claa = data.classes(idxs, :);
%     dnew.classes = claa-min(claa); % makes it zero-based
%     dnew.class_labels = data.class_labels(intersect(claa, claa)+1); % selects only labels corresponding to classes that exist in the new dataset piece

    % Reorganizes classes and class labels
    dnew.class_labels = data.class_labels;
    dnew.classes = claa;
    dnew = data_organize_classes(dnew);
    
    
    out(i) = dnew;
end;

fprintf('INFO (data_split_map()): Data was split: %d observations --> ', size(data.X, 1));
for i = 1:no_out
    if i > 1
        fprintf('+');
    end;
    fprintf('%d', length(map{i}));
end;
fprintf('.\n');
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
