% d2 = data_transform_pca(data, no_factors = 0, flag_rotate_factors = 1)
%
% Inputs
%   no_factors: number of PCA-domain features to be kept after PCA loadings
%     is calculated. 0 mean all. Obs: if you are rotating factors you'd
%     typically restrain to only a few factors.
function d2 = data_transform_pca(data, no_factors, flag_rotate_factors)

if ~exist('flag_rotate_factors', 'var')
    flag_rotate_factors = 1;
end;
if ~exist('no_factors', 'var')
    no_factors = 1;
end;

data = data_eliminate_var_0(data, 1e-10); % This is necessary, otherwise svd() will fail if there are variables with zero variance
[scores, V_star, lambdas] = princomp2(data.X);

if no_factors > 0
    no_factors_eff = min(no_factors, size(V_star, 2));
    V_star = V_star(:, 1:no_factors_eff);
else
    no_factors_eff = size(V_star, 2);
end;

if flag_rotate_factors
    V_star = rotatefactors2(V_star, 1);
end;


d2 = data;
d2 = data_transform_linear(d2, V_star, 'pca', data_normalize(data.X, 'c'));

% % % % % % d2.previous_domain = data.domain;
% % % % % % d2.previous_x = data.x;
% % % % % % 
% % % % % % d2.L = V_star;
% % % % % % d2.domain = 'pca';
% % % % % % 
% % % % % % v = 1:no_factors_eff;
% % % % % % d2.x = v;
% % % % % % d2.idx_fea = v;
% % % % % % % d2.pca_idx_fea = v;
% % % % % % 
% % % % % % % d2.pca_vars = var(d2.X);
% % % % % % % d2.pca_flag_rotated = flag_rotate_factors;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
