% d2 = data_transform_pcalda(data, no_factors = 0, flag_rotate_factors = 1, flag_modified_s_b = 0)
%
% Combo PCA->LDA transformation. Scores are no different from applying PCA
% and then LDA through the provided data_transform_pca() and
% data_transform_lda() functions. The difference here will solely be in the
% loadings.
%
% Inputs
%   no_factors: number of PCA-domain features to be kept after PCA loadings
%     is calculated. 0 mean all. Obs: if you are rotating factors you'd
%     typically restrain to only a few factors.
%   flag_modified_s_b: see calculate_scatters()
%   flag_sphere: see fisher_ld()
function d2 = data_transform_pcalda(data, no_factors, flag_rotate_factors, flag_sphere, flag_modified_s_b)

if ~exist('no_factors', 'var')
    no_factors = 0;
end;
if ~exist('flag_rotate_factors', 'var')
    flag_rotate_factors = 1;
end;

if ~exist('flag_modified_s_b', 'var')
    flag_modified_s_b = 0;
end;

if ~exist('flag_sphere', 'var')
    flag_sphere = 1;
end;


d0 = data_transform_pca(data, no_factors, flag_rotate_factors);
d1 = data_transform_lda(d0, flag_sphere, flag_modified_s_b);
d2 = d1;

d2.previous_domain = d0.previous_domain;
d2.previous_flag_wn = d0.previous_flag_wn;
d2.previous_x = d0.previous_x;
d2.L = d0.L*d1.L;
d2.domain = 'pcalda';

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
