% function data_window(data, xrange, xwindowinterval)
%
% Kills smoothly values above and below xrange. The transition zone will
% have xwindowinterval length
%
% the x* values are relative to data.x. They are converted to indexes.
%
%
% Applies a window to the coefficients to have smooth transition
% between their current values and zero.
% I chose the sigmoid function 1/(1+e^(k*x)) because it is easy to use
% This function stabilizes at around k*x = +-6
% I want this interval to be stretched to wninterval = 30 wavenumbers
% (my first attempt, may be different below), because my region of
% interest is 1770-940 and I know that 1800-900 is still ok.
function data = data_window(data, xrange, xwindowinterval)

    
nf = length(data.x);
x_per_f = abs((data.x(end)-data.x(1))/(nf-1)); % features may not be equally spaced along the x axis, this is a good average though
feainterval = xwindowinterval/x_per_f;
kscale = 12/feainterval;
fearange = v_x2ind(xrange, data.x); % features not to be zeroed
data.X = sigwindowuni(data.X, fearange(1)-feainterval/2, kscale);
data.X = sigwindowuni(data.X, fearange(2)+feainterval/2, -kscale);

% % % % fea1 = dscoef.idx_fea(1);
% % % % feaend = dscoef.idx_fea(end);
% % % % feacentre = fea1feainterval/2+fea1
% % % % 
% % % % fd = setcoef(fd, fdcoef);
% % % % 
% % % % 
% % % % % data is the one used as input for dsinput_treat_functional.m
% % % % dsinput_reconstruction_error;


function X = sigwindowuni(X, idxcentre, kscale)

sigvalues = (1./(1+exp(-kscale*((1:size(X, 2))-idxcentre))));
X = X.*repmat(sigvalues, size(X, 1), 1);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
