% peak_indexes = detect_peaks(y, threshold, min_dist = 1, no_max = Inf, min_height = 0)
% 
% y: vector of values
% threshold: threshold
%
% Detects peaks in curve and returns their indexes
function peak_indexes = detect_peaks(y, threshold, min_dist, no_max, min_height)

if ~exist('min_dist', 'var')
    min_dist = 1;
end;

if ~exist('no_max', 'var')
    no_max = Inf;
end;

if ~exist('min_height', 'var')
    min_height = 0;
end;

no_peaks = 0;
x_peaks = [];
y_peaks = [];

y = abs(y);

step = 1;
peak_indexes = [0];
no_features = length(y);

sealevel = y(1);
for i = 2:no_features
    trend = y(i)-y(i-1);

    if i > 2
        if trend > 0 && trend_last < 0
            if y(i-1) < sealevel
                sealevel = y(i-1);
            end;
            
        elseif trend < 0 && trend_last > 0 && y(i-1) >= threshold
            if no_peaks > 0 && i-peak_indexes(no_peaks) < min_dist
                % replace or ignore
                if y(peak_indexes((no_peaks))) > y(i-1)
                    % ignore
                else
                    peak_indexes(no_peaks) = i-1;
                end;
            elseif y(i)-sealevel >= min_height
                no_peaks = no_peaks+1;
                if no_peaks > step
                    % efficient way to make peak_indexes grow
                    step = step*2;
                    peak_indexes(step) = 0;
                end;

                peak_indexes(no_peaks) = i-1;
                sealevel = y(i);
            end;
        end;
    end;
    
    trend_last = trend;
end;

peak_indexes = peak_indexes(1:no_peaks);

if length(peak_indexes) > no_max
    [dummy, idx] = sort(y(peak_indexes), 'descend');
    peak_indexes = peak_indexes(idx(1:no_max));
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
