% peak_indexes = detect_peaks(y, threshold, min_dist = 1, no_max = Inf, min_height = 0, no_conv = 6)
% 
% y: vector of values
% threshold: threshold
%
% Detects peaks in curve and returns their indexes
function peak_indexes = detect_peaks(y, threshold, min_dist, no_max, min_height, no_conv)

if ~exist('no_conv', 'var')
    no_conv = 6;
end;



f_ = [1, 1, 1];
f = [1];
for i = 1:no_conv
    f = conv(f, f_);
end;
f = f/sum(f);

off = (length(f)-1)/2;

% (almost) eliminates transient effects
y_ = [ones(1, off)*y(1) y ones(1, off)*y(end)];

ygrab = conv(y_, f);
ygrab = ygrab(1+2*off:end-2*off);


if ~exist('min_dist', 'var')
    min_dist = 1;
end;

if ~exist('no_max', 'var')
    no_max = Inf;
end;

if ~exist('min_height', 'var')
    min_height = 0;
end;

no_peaks = 0;
x_peaks = [];
y_peaks = [];

ygrab = abs(ygrab);

step = 1;
peak_indexes = [0];
no_features = length(ygrab);


allpeaks = detect_peaks(y, threshold, 0, Inf, 0);


sealevel = ygrab(1);
for i = 2:no_features
    trend = ygrab(i)-ygrab(i-1);
    
    flag_peak = 0;

    if i > 2
        if trend > 0 && trend_last < 0
            if ygrab(i-1) < sealevel
                sealevel = ygrab(i-1);
            end;
            
        elseif trend < 0 && trend_last > 0 && ygrab(i-1) >= threshold
            if no_peaks > 0 && i-peak_indexes(no_peaks) < min_dist
                % replace or ignore
                if ygrab(peak_indexes((no_peaks))) > ygrab(i-1)
                    % ignore
                else
                    flag_peak = 1;
                end;
            elseif ygrab(i)-sealevel >= min_height
                no_peaks = no_peaks+1;
                if no_peaks > step
                    % efficient way to make peak_indexes grow
                    step = step*2;
                    peak_indexes(step) = 0;
                end;

                flag_peak = 1;
                sealevel = ygrab(i);
            end;
        end;
    end;
    
    if flag_peak
        flagfound = 0;
        for j = 1:length(allpeaks)
            if allpeaks(j) >= i-1
                if j == 1
                    peak_indexes(no_peaks) = allpeaks(j);
                elseif allpeaks(j) - (i-1) <= (i-1) - allpeaks(j-1)
                    peak_indexes(no_peaks) = allpeaks(j);
                else
                    peak_indexes(no_peaks) = allpeaks(j-1);
                end;
                flagfound = 1;
                break;
            end;
        end;
        if ~flagfound
            peak_indexes(no_peaks) = allpeaks(end);
        end;
    end;
% % peak_indexes(no_peak) = allpeaks(j);   

    trend_last = trend;
end;

peak_indexes = peak_indexes(1:no_peaks);

if length(peak_indexes) > no_max
    [dummy, idx] = sort(ygrab(peak_indexes), 'descend');
    peak_indexes = peak_indexes(idx(1:no_max));
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
