% function data = data_draw_covariance(data, which = 'c', y_ref = mean(data.X, 1))
%
% which: 'c': covariance; 'w': within-class covariacne matrix; 'b': between-class covariance matrix
function draw_covariance(C, x, y)
% Plots covariance matrices

nf = size(C, 1);

if ~exist('x', 'var')
    x = 1:nf;
end;


if ~exist('y', 'var')
  y = [];
end;


[XX, YY] = meshgrid(x, x);

x1 = x(1);
x2 = x(end);
xmin = min(x1, x2);
xmax = max(x1, x2);
xrange = xmax-xmin;
flag_reverse = x1 > x2;

pcolor(XX, YY, C);
shading interp;
hold on;
% contour(XX, YY, C, 4, 'LineWidth', 20, 'Color', 'k');

if ~isempty(y)
    k = 100; % scaling for reference spectrum
    z = .1*ones(1, length(x));
    colour = 'k'; %[.5, .5, .5];
    width = 2;
    plot3(x, x2-y*k, z, 'Color', colour, 'LineWidth', width);
    plot3(x2-y*k, x, z, 'Color', colour, 'LineWidth', width);
else
    k = 0;
end;

plot3([x2, x2, x1, x1, x2], [x1, x2, x2, x1, x1], [.1, .1, .1, .1, .1], 'k');


set(gca, 'XLim', [xmin-xrange*.02-k, xmax+xrange*.02]);
set(gca, 'YLim', [xmin-xrange*.02-k, xmax+xrange*.02]);
xlabel('Wavenumber (cm^{-1})');
ylabel('Wavenumber (cm^{-1})');
if flag_reverse
    set(gca, 'XDir', 'reverse');
    set(gca, 'YDir', 'reverse');
end;
%     set(gca, 'XTick', [1210, 1645]);
%     set(gca, 'YTick', [1210, 1645]);
box off;

format_frank(gcf, 1);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
