% function draw_loadings_complete(data, L, legends, flag_abs, threshold, flag_print_peaks, flag_plot_peaks)
%
% Performs a complete drawing of a loadings curve,
%
% peaks, threshold line, mean spectrum and the loadings curve, of course.
%
% Inputs:
%   DATA_: data to extract the mean spectrum from
%   x: vector of wavenumbers
%   L: loadings matrix
%   threshold: minimum amplitude to be considered
%   flag_abs: indicates whether y contains absolute value of loadings of
%             loadings itself
function draw_loadings_complete(data, L, legends, flag_abs, threshold, flag_print_peaks, flag_plot_peaks)

if ~exist('flag_abs', 'var')
    flag_abs = 0;
end;
if ~exist('threshold', 'var')
    threshold = 1;
end;
if ~exist('flag_print_peaks', 'var')
    flag_print_peaks = 0;
end;
if ~exist('flag_plot_peaks', 'var')
    flag_plot_peaks = 0;
end;


if flag_abs
    ymin = 0;
    offmin = 0;
    L = abs(L);
else
    ymin = min(min(L));
    offmin = 0.1;
end;
ymax = max(max(L));
ymaxabs = max(max(abs(L)));
flag_bother_peaks = threshold < 1 && (flag_print_peaks || flag_plot_peaks);
if flag_bother_peaks
    threshold = threshold*ymaxabs;
end;
draw_zero_line(data.background_x);
hold on;
% if flag_abs
%     mean_scale = ymaxabs;
% else
%     mean_scale = ymax;
% end;
data_plot_indicator_spectrum(data, ymax); %mean_scale);

no = size(L, 2);
if ~isempty(data.previous_x)
    x = data.previous_x;
else
    x = data.x;
end;
for i = 1:no
    y = L(:, i)';
    
    hh = plot_curve_pieces(x, y, 'Color', find_color(i), 'LineWidth', 2);
    handles(i) = hh{1};

    
    if flag_bother_peaks
        if flag_plot_peaks
            plot_peaks(x, y, threshold);
        end;

        if flag_print_peaks
            if exist('legends', 'var')
                s = sprintf('for ''%s''', legends{i});
            else
                s = sprintf('%d', i);
            end;

            fprintf('---------------- Peaks %s -----------------\n', s);

            print_peaks(x, y, threshold);
        end;
    end;
end;

% Plots threshold line
if flag_bother_peaks && 0  % I have purposely deactivated threshold line drawing
    y_line = ones(size(L, 1), 1)*threshold;
    plot(x, y_line, 'r--');
    if ~flag_abs
        plot(x, -y_line, 'r--');
    end;
end;


% Formatting
format_frank();
if data.previous_flag_wn
    format_wn([data.background_x(1), data.background_x(end)]);
end;
if exist('legends', 'var')
    legend(handles, legends);
end;
set(gca, 'Ylim', [ymin*1.1, ymax*1.1]);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
