% [vv, lambdas] = eig_ordered(M)
%
% Returns desc-ordered eigenvectors and eigenvalues.
function [vv, ll] = eig_ordered(M)

r = rank(M);
no_cols = size(M, 2);

% [vv, dd] = eigs(M, r); % eigenvectors, eigenvalues
[vv, dd] = eig(M); % eigenvectors, eigenvalues

% the eig() function gives eigenvalues in ascending order, however I have
% experienced the opposite with a low-rank matrix. 

% Also this time I am not taking into account the presence of NaN eigenvalues.

% This creates an index vector at column 2 of the 'lambdas' variable
lambdas = diag(dd);
lambdas(:, 2) = (1:no_cols)';
lambdas = sortrows(lambdas);

% However, the index vector is in ascending order and we want the opposite
indexes = lambdas(end:-1:1, 2);
vv = vv(:, indexes);
vv = vv(:, 1:r);

ll = lambdas(end:-1:1, 1)';
ll = ll(1:r);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
