% function ranking = feasel_get_features_ranking(o, mode)
%
% mode: 'sum': sum performances
%       'min': minimum
function ranking = feasel_get_features_ranking(o, mode)

if ~exist('mode', 'var')
    mode = 'min';
end;

logg = o.logs(1);

nf = size(o.ds.X, 2);
no_cases = length(logg.cases);


if mode == 'min'
    ranking = ones(1, nf)*Inf;
else
    ranking = zeros(1, nf);
end;


for i = 1:no_cases
    % Could square performances, but for the moment I will just sum them
    if strcmp(mode, 'sum')
        ranking(logg.cases(i).idxs) = ranking(logg.cases(i).idxs)+mean(logg.cases(i).performances(:));
    elseif strcmp(mode, 'min')
        idxs = logg.cases(i).idxs;
        perf = mean(logg.cases(i).performances(:));
        for j = 1:length(idxs)
            ranking(idxs(j)) = min(ranking(idxs(j)), perf);
        end;
    else
        error('Invalid performance ranking mode: %s', mode);
    end;
end;
    
    
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
