% function o = feasel_validate(o, idxs_candidates)
%   o: feature selection object
%   idxs_candidates: cell of feature index lists
function [o, log] = feasel_validate(o, dss, idxs_candidates)
 


no_candidates = length(idxs_candidates);
no_classes = length(o.ms.class_labels);
log = feaselvalidationlog_new();
performances = [];

nf_save = -1;
flag_same_nf = 1; % whether all candidates have the same number of features

for i_candidate = 1:no_candidates
    idxs_fea = idxs_candidates{i_candidate};
    
    log.cases(i_candidate).idxs = idxs_fea;

    if flag_same_nf
        nf = length(idxs_fea);
        if nf_save ==  -1
            nf_save = nf;
        elseif nf ~= nf_save
            flag_same_nf = 0;
        end;
    end;
    
    fprintf('\n\n()()()()()()()() idxs candidate %d/%d. ()()()()()()()()\n\n', i_candidate, no_candidates);
    
%     cc = zeros(no_classes, no_classes); % confusion matrix
    ms = modelset_boot(o.ms, data_select_features(o.ds, idxs_fea, 'i'));
    for i_rep = 1:o.no_reps
        fprintf('$*$*$*$ Session %d/%d. $*$*$*$\n', i_rep, o.no_reps);
        
        d_train = data_select_features(dss(i_rep).train, idxs_fea, 'i');
        d_test = data_select_features(dss(i_rep).test, idxs_fea, 'i');
        
        ms = modelset_train(ms, d_train);
        ms = modelset_estimate(ms, d_test);
%         cc = cc+est_get_confusion(ms.o_est, d_test, 0);
%         sensspec = calc_sens_spec(cc);
        cc = est_get_confusion(ms.o_est, d_test, 0);
        log.cases(i_candidate).performances(i_rep) = calc_sens_spec(cc, 1);
    end;

    performances(i_candidate) = mean(log.cases(i_candidate).performances);
end;


if flag_same_nf
    log.no_features = nf_save;
end;

[val, log.idx_best] = max(performances);

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
