% format_frank(F, scale=1, additional_handles)
%
% Formats a figure according to Frank's rules (Times New Roman)
%
% F defaults to gcf()
function format_frank(F, scale, handles)
global FONT FONTSIZE;

if ~exist('F', 'var')
    F = gcf();
end;

if isempty(FONT)
    font = 'Times';
    disp('Warning: FONT global not present, using default ''Times''.');
else
    font = FONT;
end;
if isempty(FONTSIZE)
    fontsize = 36;
    disp('(format_frank()) Warning: FONTSIZE global not present, using default 36.');
else
    fontsize = FONTSIZE;
end;
    

if ~exist('scale', 'var')
    scale = 1;
end;

a = get(F, 'CurrentAxes');
l1 = get(a, 'Xlabel');
l2 = get(a, 'Ylabel');
l3 = get(a, 'Zlabel');
t = get(a, 'Title');

if ~exist('handles', 'var')
    handles = [];
end;
handles = cat(2, handles, [a, l1, l2, l3, t]);

for i = 1:length(handles)
    o = handles(i);
%     set(o, 'FontName', 'Times New Roman');
    set(o, 'FontName', font);
    set(o, 'FontSize', fontsize*scale);
end;

set(a, 'Box', 'on');
set(a, 'LineWidth', 2*scale);
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
