disp('This program performs stepwise forward feature selection to determine')
disp('the best few wavenumbers for classification, aiming to interpret these')
disp('as biomarkers');

% % % % % % addpath('../summer');
% % % % % % load_current_dataset();
% % % % % % colors_markers();
% % % % % % 
% % % % % % nf = size(dswork.X, 2);
% % % % % % 
% % % % % % a_options = {'Agent vs. vehicle control', 'Non-transformed vs. Transformed per tray', 'Non-transformed vs. Transformed overall'};

%%

colors_markers();




while 1
    clc;
    if exist('datasets')
        disp('|| Datasets:')
        for i = 1:length(datasets)
            disp(datasets(i).name);
        end;
    end;
    
    if exist('results')
        disp('|| Results:')
        for i = 1:length(results)
            disp(mat2str(results(i).wns));
        end;
    end;
    
    
    option = menu('Main menu', {'Mount datasets', 'Select datasets', 'Run session ', 'Visualize results', 'Save results', 'Load results'}, 'End');
    if option == 0
        return;
    elseif option == 1
        dsinput_name = input('Input dataset name: ', 's');
        if ~isempty(dsinput_name)
            dswork = eval(dsinput_name);
        
            option2 = menu('Dataset split type', {'Hierarchical', 'Agent vs. VC', 'None'}, 'Cancel');
            if option2 == 1
                levels_main = input('Main level(s) (example: [1]): ');
                if ~isempty(levels_main)
                    clear datasets;
                    pieces = data_split_classes(dswork, levels_main);
                    for i = 1:8
                        datasets(i).data = pieces(i);
                        dtemp = data_select_hierarchy(datasets(i).data, levels_main);
                        datasets(i).name =  dtemp.class_labels{1};
                    end;
                end;
            elseif option2 == 2
                idx_vc = input('Vehicle control class index (example: 1): ');
                if ~isempty(idx_vc)
                    clear datasets;
                
                    pieces = data_split_classes(dswork);
                    ii = 0;
                    for i = 1:length(pieces)
                        if i ~= idx_vc
                            ii = ii+1;
                            datasets(ii).data = data_merge(pieces([idx_vc, i]));
                            datasets(ii).name = [pieces(idx_vc).class_labels{1} ' vs. ' pieces(i).class_labels{1}];
                        end;
                    end;
                end;
            elseif option2 == 3
                clear datasets;
               datasets(1).data = dswork;
               datasets(1).name = 'All';
            end;
        end;
    elseif option == 2
        idxs = input('Type the indexes of the datasets to be kept ([1, 2, ...]): ');
        if ~isempty(idxs)
            datasets = datasets(idxs);
        end;
    elseif option == 3
        flag_ok = 1;

        max_vars = input('Maximum number of variables: ');
        if isempty('max_vars')
            flag_ok = 0;
        end;
        
        if flag_ok
            crossval_no_reps = input('k for k-fold cross-validation: ');
            
            if isempty(crossval_no_reps)
                flag_ok = 0;
            end;
        end;
        
        
        if flag_ok
            clear results;
            nc = length(datasets);
            rt = cell(nc, 2);
    %         rt{1, 1} = a_options{option};

% % %             idxss = zeros(nc, max_vars);

            for i = 1:nc
                davez = datasets(i).data;

                modelset01 = modelset_new(@cla_new, 0);
                modelset01 = modelset_create_models(modelset01, davez);
                modelset01 = modelset_setbatch(modelset01, {'type', 'linear', ...
                'flag_class2mo', 1});
                modelset01 = modelset_boot(modelset01, dswork);


                o = feasel_new();
                o.ms = modelset01;
                o.max_vars = max_vars;
                o.no_reps = 1;
                o.validation_type = 'bootstrap';
                o.perc_train = 0.9;
                o.min_vars = 1;
                o.flag_forward = 1;

                o.ds = davez;

                o = feasel_go_stepwise(o);

                rt(i, 1:2) = {datasets(i).name, mat2str(round(davez.x(o.logs(end).cases(o.logs(end).idx_best).idxs)*10)/10)};
% % % %                 idxss(i, :) = davez.x(o.idxs);

%                 o.ds = [];
                results(i).o = o;
                results(i).wns = round(davez.x(o.idxs)*10)/10;
                results(i).x = davez.x;
                results(i).name = datasets(i).name;
            end;
        end;

        save_txt_file(csv_from_cell(rt), find_filename(['warforterritory'], '', 'txt'));

        input('--- Pause ---');

                
    elseif option == 4
        while 1
            option2 = menu('Visualization', {'#wn vs. classification rate', 'evolution', 'biomarker balls'}, 'Cancel');

            if option2 == 0
                break;
            elseif option2 == 1
                % Plots the classification rate versus the number of wavenumbers
                figure;
                for i = 1:length(results)
                    hh(i) = plot([results(i).o.history.performance]*100, 'LineWidth', 5, 'Color', find_color(i));
                    hold on;
                end;

                xlabel('Number of variables');
                ylabel('Classification rate (%)');
                legend(hh, {results.name});
                format_frank(gcf, 1.8);
            elseif option2 == 2
                % Evolution
                flag_ok = 1;
                if length(results) > 1
                    idx = input('Enter the result index to see the evolution: ');
                    if isempty(idx)
                        flag_ok = 0;
                    end;
                else
                    idx = 1;
                end;
%                 x = results(idx).x;
%                 o = ;
                

                curves = feasel_curves_from_cases(results(idx).o);
                
                np = length(curves);
                figure;
                for i = 1:np
                    subplot(np, 1, i);
                    x = results(idx).x(curves(i).idx);
                    y = curves(i).performance;
                    plot_curve_pieces(x, y);
                    [va, in] = max(y);
                    hold on;
                    plot(x(in), y(in), 'rx');
                    set(gca, 'XDir', 'reverse');
                    if i == 1
                        title('None before');
                    else
                        title(sprintf('%4.0f added', results(idx).wns(i-1)));
                    end;
                end;
                    
                
            elseif option2 == 3
                % Plots the biomarker balls
                figure;

                no_markers = length(results(1).wns);
                
                
                xy = [];
                flag_bm1 = 0;
                for i = 1:length(results)
                    if length(results(i).o.ds.class_labels) == 2
                        % BM1 can only be used if the individual dataset have only 2 classes

                        pieces = data_split_classes(results(i).o.ds);
                        m = mean(pieces(2).X)-mean(pieces(1).X);
                        

                        peakidx = detect_peaks2(abs(m), 0, 11, 5, .1*max(abs(m)), 3);
                        
                        xy(1, i).x = results(i).x(peakidx);
                        xy(1, i).y = abs(m(peakidx));
                        flag_bm1 = 1;
                    end;
    
                    
                    % BM2
                    curves = feasel_curves_from_cases(results(i).o);
                    y = curves(1).performance;
                    peakidx = detect_peaks2(y, 0, 11, no_markers, .2*(max(y)-min(y)), 7); % .65: threshold; 11: minimum distance between peaks; 7: number of convolutions

                    xy(2, i).x = results(i).x(peakidx);
                    xy(2, i).y = y(peakidx);

                    
                    %BM3
                    xy(3, i).x = results(i).wns;
                    xy(3, i).y = linspace(1, 0.5, length(results(1).wns));
                end;
                
%                 set(gca, 'Interpreter', 'TeX');
                hh = draw_markers(xy, {results.name}, dswork, 0);
                
                legends = {'Univariate classification rate (BM2)', 'Best jointly distinguishing wavenumbers (BM3)'};
                if flag_bm1
                    legends = {'Difference between means (BM1)', legends{1}, legends{2}};
                end;
                legend(hh, legends);
            end;
        end;
    elseif option == 5
        filename = input('Type file name to save: ');
        if ~isempty(filename)
            save(filename, 'results');
        end;
    elseif option == 6
        filename = input('Type file name to load: ');
        if ~isempty(filename)
            load(filename);
        end;
    end;        
end;


% % % % option = menu('Select the desired test', ...
% % % % a_options, 'cancel');
% % % % if option == 0
% % % %     return;
% % % % % % end;




% % % % % % % % % % % clear datasets dataset_names;
% % % % % % % % % % % 
% % % % % % % % % % % if option == 1 % Agent vs. VC
% % % % % % % % % % %     dswork = data_select_hierarchy(dswork, 1);
% % % % % % % % % % %     pieces = data_split_classes(dswork);
% % % % % % % % % % %     tray_ref = 1; % DMSO: Control
% % % % % % % % % % % 
% % % % % % % % % % %     ii = 0;
% % % % % % % % % % %     for i = 1:length(pieces)
% % % % % % % % % % %         if i ~= tray_ref
% % % % % % % % % % %             ii = ii+1;
% % % % % % % % % % %             datasets(ii) = data_merge(pieces([tray_ref, i]));
% % % % % % % % % % %             dataset_names{ii} = ['VC vs. ' pieces(tray_ref).class_labels{1}];
% % % % % % % % % % %         end;
% % % % % % % % % % %     end;
% % % % % % % % % % % 
% % % % % % % % % % % elseif option == 2 % N vs. T per tray
% % % % % % % % % % %     pieces0 = data_split_classes(dswork);
% % % % % % % % % % %     for i = 1:8
% % % % % % % % % % %         datasets(i) = data_merge(pieces0((i-1)*2+[1, 2]));
% % % % % % % % % % %         dtemp = data_select_hierarchy(datasets(i), 1);
% % % % % % % % % % %         dataset_names{i} =  dtemp.class_labels{1};
% % % % % % % % % % %     end;
% % % % % % % % % % % 
% % % % % % % % % % % elseif option == 3 % n vs. t overall
% % % % % % % % % % %    datasets = data_select_hierarchy(dswork, 2);
% % % % % % % % % % %    dataset_names = {'N vs. T all'};
% % % % % % % % % % % 
% % % % % % % % % % % end;
% % % % % % % % % % % nc = length(datasets);
% % % % % % % % % % % 






% % % % % % % %%
% % % % % % % 
% % % % % % % rt = cell(nc+1, 2);
% % % % % % % rt{1, 1} = a_options{option};
% % % % % % % 
% % % % % % % idxss = zeros(nc, max_vars);
% % % % % % % 
% % % % % % % for i = 1:nc
% % % % % % %     davez = datasets(i);
% % % % % % %     
% % % % % % %     modelset01 = modelset_new(@cla_new, 0);
% % % % % % %     modelset01 = modelset_create_models(modelset01, davez);
% % % % % % %     modelset01 = modelset_setbatch(modelset01, {'type', 'linear', ...
% % % % % % %     'flag_class2mo', 1});
% % % % % % %     modelset01 = modelset_boot(modelset01, dswork);
% % % % % % % 
% % % % % % % 
% % % % % % %     o = feasel_new();
% % % % % % %     o.ms = modelset01;
% % % % % % %     o.max_vars = max_vars;
% % % % % % %     o.crossval_no_reps = 2;
% % % % % % %     o.min_vars = 1;
% % % % % % %     o.flag_forward = 1;
% % % % % % %     
% % % % % % %     o.ds = davez;
% % % % % % %     
% % % % % % %     o = feasel_go_stepwise(o);
% % % % % % %     
% % % % % % %     rt(i+1, 1:2) = {dataset_names{i}, mat2str(round(davez.x(o.idxs)*10)/10)};
% % % % % % %     idxss(i, :) = davez.x(o.idxs);
% % % % % % % end;
% % % % % % % 
%%

% % % % % % % % Plots the classification rate versus the number of wavenumbers
% % % % % % % 
% % % % % % % figure;
% % % % % % % plot([o.history.performance]*100, 'LineWidth', 5);
% % % % % % % xlabel('Number of variables');
% % % % % % % ylabel('Classification rate (%)');
% % % % % % % format_frank(gcf, 1.8);
% % % % % % % 
% % % % % % % 
% % % % % % % %%
% % % % % % % 
% % % % % % % % Plots the biomarker balls
% % % % % % % 
% % % % % % % figure;
% % % % % % % draw_markers(idxss, dataset_names, [], dswork, 1);
% % % % % % % 
% % % % % % % 
% % % % % % % %%
% % % % % % % save('warforterritory', 'rt');
% % % % % % % save_txt_file(csv_from_cell(rt), find_filename(['warforterritory_' a_options{option}], '', 'txt'));

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
