% function [model, est] = knn_estimate(model, data)
%
% Outputs:
%   model: the model itself
%   est: estimation structure
function [model, est] = knn_estimate(model, data)
no_obs_test = size(data.X, 1);
no_obs_train = size(model.X, 1);


no_classes = length(model.class_labels);

votes = zeros(no_classes, 2);
est = est_new_from_model_data(model, data);

tic();
for i = 1:no_obs_test
    % vector to be tested
    v_test = data.X(i, :);

    %%%%%%%%%%%%%%%%%%%%%%%%%%
    % Mounts a distance vector with a second column which is the class
    
    % computes a vector of squared distances
    dists = [zeros(no_obs_train, 1) model.classes];    % puts classes on right column for further sort
    for j = 1:no_obs_train
        v_temp = model.X(j, :)-v_test; % row vector
        dists(j, 1) = v_temp*v_temp';
    end;

    dists = sortrows(dists);
    
    % inits votes matrix. Each column is (number_of_votes, class)
    votes(:, 1) = 0;
    votes(:, 2) = 0:no_classes-1;
    
    for j = 1:min(no_obs_train, model.k)
        votes(dists(j, 2)+1, 1) = votes(dists(j, 2)+1, 1)+1;  % Here a weight on the vote can be put 
    end;

    votes = sortrows(votes);
    decision = votes(no_classes, 2); % The pool is in ascending order, so takes last one

    est.classes(i) = decision;
end;
model.time_estimate = toc();

est.Y = est.classes; % k-NN does not make estimations, only classifications, so the estimation vector is assigned the same value as the classification vector.

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
