% function load_mat_file(filename, range = [])
%
% Loads a data structure which has been previously saved into a .mat file.
%
% range is an opportunity to pass the initial and final values of the feature labels.
%
% If DATA.x is not saved in the .mat file and range has not been passed, the default [1801.47, 898.81] range will be
% used.
% 
function load_mat_file(filename, range)
global DATA;

load(filename);

% TODO This is a hack present until I do a proper wavenumber record
% while importing Pirouette files and make MATLAB import and record
% these information (and re-generate the .mat files).

if exist('range', 'var')
    DATA.x = linspace(range(1), range(2), size(DATA.X, 2));
else
    if ~exist('DATA.x')
        DATA.x = linspace(1801.47, 898.81, size(DATA.X, 2));
    end;
end;

DATA.file_name = filename;
DATA.file_type = 'mat';

DATA.background_x = DATA.x;
DATA.background_y = mean(DATA.X, 1);


% Backward compatibility
if ~exist('DATA.flag_wn')
    DATA.flag_wn = 1;
    DATA.previous_flag_wn = 1;
end;


% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
