% function a = modelset_boot(a, data)
%
% Modelset boot: to be called when data with new characteristics (features, labels) will be used for the first time.
% 
% *Important*: data must contain samples from all classes. 
%
% In the future if new classes are introduced, there must be a
% way to add models to the modelset
%
% This function is much like modelset_train, it just calls a different function
%
function a = modelset_boot(a, data)

[a, data] = modelset_prepare_data(a, data);

if a.flag_split
    pieces = data_split_classes(data);
    no_models = length(a.models);
    
    for im = 1:no_models
        cl = a.class_labelss{im};
        idxs_pieces = [];
        clear piece_list;
        for il = 1:length(cl)
            idx = find(strcmp(cl{il}, data.class_labels));
            if isempty(idx)
                disp(['modelset_boot(): warning: class ' cl{il} ' not present in data']);
            else
                idxs_pieces(il) = idx;
                piece_list(il) = pieces(idx);
            end;
        end;
        fprintf('modelset_boot(): booting model %d/%d...\n', im, no_models);
        a.models{im} = feval(a.models{im}.f_boot, a.models{im}, data_merge(piece_list));
    end;
else
% TODO: it is not being checked whether data has classes not present in modelset.class_labels.
   a.models{1} = feval(a.models{1}.f_boot, a.models{1}, data);
end;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
