% function a = modelset_boot(a, data)
%
% Modelset_create_models: to be called when data with new characteristics (features, labels) will be used for the first time.
% 
% *Important*: data must contain samples from all classes. 
%
% In the future if new classes are introduced, there must be a
% way to add models to the modelset
function a = modelset_create_models(a, data)

a.class_labels = data.class_labels;
a.models = {};
a.class_labelss = {};

if a.flag_split
    % class_labels order is vital.
    pieces = data_split_classes(data);
    no_classes = length(pieces);

    i = 1;
    for i1 = 1:no_classes-1
        for i2 = i1+1:no_classes
           % merged dataset of 2 classes is used to boot model.
           idxs = [i1, i2];

           a.models{i} = feval(a.fcn_new_model, sprintf('''%s'' vs. ''%s''', pieces(i1).class_labels{1}, pieces(i2).class_labels{1}));
           
           % Yes, class labels will have only the classes that the model
           % will be trained with. It makes sense, since the MIMO models
           % won't have to deal with unnecessary outputs
           a.class_labelss{i} = a.class_labels([i1, i2]);
           i = i+1;
        end;
    end;
else
    a.models{1} = feval(a.fcn_new_model, 'Multi-class model');
end;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
