% function a = modelset_plot_mf(a, idxs_fea)
%
% Inputs:
%   a: model set
%   idxs_fea
%
function a = modelset_plot_mf(a, data, idxs_fea)

% determines range
X_ = data.X(:, idxs_fea);
mins = min(X_);
maxs = max(X_);

% determines rows and cols
ratio = 3/4; % desired cols/rows ratio
no_fea = length(idxs_fea);
cols = ceil(sqrt(no_fea*ratio));
rows = ceil(no_fea/cols);

% plot parameters
no_points = 200;
x = linspace(min(mins), max(maxs), no_points);


for i_plot = 1:no_fea
    idx_fea = idxs_fea(i_plot);
    
    % plot initialization
    handles = []; % for legend, later
    labels = {};
    subplot(rows, cols, i_plot);
    
    for i_model = 1:length(a.models)
        model = a.models{i_model};
        no_groups = length(model.rule_groups);
        
        for i_group = 1:no_groups
            o = model.rule_groups{i_group};
            
            for i_rule = 1:min(5, o.no_rules)
                y = zeros(1, no_points);
                center = o.rule_centres(i_rule, idx_fea);
                radius = o.rule_radii(i_rule, idx_fea);
                for i_x = 1:no_points
                    y(i_x) = feval(model.f_mf, x(i_x), center, radius);
                end;
                
                handle = plot(x, y, 'Color', find_color(i_group), 'LineStyle', '-');
                hold on;
                
                if i_plot == 1 && i_rule == 1 && i_model == 1
                    handles(end+1) = handle;
                    labels{end+1} = o.name;
                end;
            end;
        end;
    end;

    if i_plot == 1
        legend(handles, labels);
    end;
    ylabel(sprintf('Feature %g', data.x(idx_fea)));
    set(gca, 'XLim', [min(mins) max(maxs)]);
    format_frank();
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
