% result = peak_closest(db, a)
% 
% returns index of peak closest to a
%
% a can be either the number of a wavenumber or
% the wavenumber itself, because it is easy to distinguish one from the
% other
%
% result is an index of an element in db, such as db.names(result),
% db.centres(result) of db.indexes(result)
function result = peak_closest(db, a)


flag_wn = a > 250;

if flag_wn
    v = db.centres;
else
    v = db.indexes(end:-1:1);
end;

result = 0;
for i = 1:length(v)
    if v(i) < a
        if i == 1
            result = i;
        elseif (a-v(i)) < (v(i-1)-a)
            result = i;
        else
            result = i-1;
        end;
        break;
    end;
end;
if result == 0
    result = length(v);
end;

if ~flag_wn
    result = length(v)+1-result;
end;

        

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
