% function P = penalty_matrix(nf, dcoeff)
%
% Inputs:
%   nf: number of features
%   dcoeff: coefficient vector for 0th, 2nd, 3rd derivative and so on
%
% Output:
%   P: a [nf]x[nf] symmetric matrix. It contains a weighted sum of
%   different matrices D_i'*D_i. the coefficients of the sum are given by
%   dcoeff. D_0 is eye(nf, nf). D_i is the i-th order differential operator
%   such that D_i*x = diff(x, i).
function P = penalty_matrix(nf, dcoeff)

P = zeros(nf, nf);
for i = 1:length(dcoeff)
    D = diff_operator(nf, i-1);
    P = P+dcoeff(i)*(D'*D);
end;
% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
