% Loads spectra and classification from database
%
% Makes up a 'data' structure with
%   - X: data matrix (rows are spectra, columns are wavenumbers)
%   - classes: classification index (0, 1, 2 and so on), one for each row in data.
%   - idspectrum_s: a column vector containing the same number of row as
%     DATA. Its elements are the spectrum id corresponding to each row
%     in DATA
%   - no_wavenumbers: matches number of columns in data.X but comes from a
%     different source
%   - class_labels: legends for each class
%   - idjudge_ref: db:judge.id
function read_spectra_with_classification()
global IDEXPERIMENT NO_WAVENUMBERS IDJUDGE_REF CLASS_LABELS DATA

assure_connected()
% assure_reference_judge_selected()



disp('-- Doing the BIG select ... --')
% [values, params_s] = mysql(sprintf(['select series.value, spectrum_judge.params from series ' ...
% 'left join spectrum_judge on spectrum_judge.idspectrum = series.idspectrum and spectrum_judge.idjudge = %d ' ...
% 'left join spectrum on spectrum.id = series.idspectrum where series.idexperiment = %d and spectrum.flag_active = 1 ' ...
% 'order by series.idspectrum, series.id'], IDJUDGE_REF, IDEXPERIMENT));

% After I started to use Matlab R2008a, series' values are coming as
% integers. The workaround was multiply series.values by 100000 upon select and then
% divide the 'values' vector by 100000. The number 100000 was chosen
% because Opus saves Pirouette .dat files with 5 decimal digits.

[params_s, values, idspectrum_s, idcolony_s, file_names, colony_codes] = mym(sprintf([ ...
'select spectrum_judge.params, series.value*100000, spectrum.id, colony.id, spectrum.file_name, colony.code from series ' ...
'left join spectrum_judge on spectrum_judge.idspectrum = series.idspectrum and spectrum_judge.idjudge = %d ' ...
'left join spectrum on spectrum.id = series.idspectrum ' ...
'left join colony on colony.id = spectrum.idcolony ' ...
'where series.idexperiment = %d and spectrum.flag_active = 1 ' ...
'order by spectrum.idcolony, series.idspectrum, series.id'], IDJUDGE_REF, IDEXPERIMENT));
values = values/100000;

disp('-- ... done --')

no_values = size(values, 1);
no_observations = no_values/NO_WAVENUMBERS;


DATA = data_new();
DATA.class_labels = CLASS_LABELS;
DATA.X = zeros(no_observations, NO_WAVENUMBERS);
DATA.classes = zeros(no_observations, 1);
DATA.idspectrum_s = zeros(no_observations, 1);
DATA.idcolony_s = zeros(no_observations, 1);
DATA.file_names = cell(no_observations, 1);
DATA.colony_codes = cell(no_observations, 1);

n = 1; % pointer over DATA
nn = 0;
for i = 1:no_observations
    DATA.file_names{i} = file_names{n};
    DATA.colony_codes{i} = colony_codes{n};
    DATA.idspectrum_s(i) = idspectrum_s(n);
    DATA.idcolony_s(i) = idcolony_s(n);
    
    % finds class index out from class code
    params = char(params_s{n})';

    quote_indexes = regexp(params, '"');
    if size(quote_indexes) < 2
        class_index = -1;
    else
        code = params(quote_indexes(1)+1:quote_indexes(2)-1); % extracts code from param string
        find_indexes = find(strcmp(CLASS_LABELS, code));
        if size(find_indexes, 1) == 0
            error(sprintf('Class code "%s" invalid.', code))
        end
        class_index = find_indexes(1);
    end
    DATA.classes(i) = class_index-1;

    for j = 1:NO_WAVENUMBERS
        DATA.X(i, j) = values(n);
        n = n+1;
    end
    
    nn = nn+1;
    if nn == 199 % arbitrary value
        disp(sprintf('-- %5.1f %% --', n/no_values*100))
        nn = 0;
    end
end
    
    

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
