% function out = svm_new(name)
%
% Creates a new Support Vector Machine (SVM) model
%
% Inputs:
%   name: string containing a name for the model (optional)
%
% Outputs:
%   out: the model
function out = svm_new(name)

if exist('name', 'var')
    name = 'SVM Model';
end;
out = model_new(name);

%%%
% General fields
out.important_prop_names = {'time_train', 'time_estimate', 'no_svs'};
out.important_prop_descriptions = {'Training time (seconds)', 'Testing time (seconds)', 'Number of support vectors'};

out.f_train = 'svm_train'; % function that will train the model
out.f_test = 'svm_estimate'; % function that will train the model
out.f_boot = 'svm_boot'; % function that will boot the model. Usually not changed.

% whether classes must be converter into multiple-output boolean targets.
% This is meaningless in SVM
out.flag_class2mo = 0; 


% SVM-specific parameters
out.c = 1;
out.gamma = 1;

out.no_svs = 0;


% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
