% function                 [ypoll] = ypoll_new_poll(colony_codes, classes1, class_labels)
%           [ypoll, ypoll_correct] = ypoll_new_poll(colony_codes, classes1, class_labels, classes2)
%
% Determines the classes from major voting inside each colony.
%
% The 2 parameter output is equivalent to calling the function again
% passing (data, data.classes) as parameters.
function varargout = ypoll_new_poll(colony_codes, classes1, class_labels, classes2)

flag_2 = exist('classes2', 'var');

[codes_sorted, idxs] = sort(colony_codes);

varargout = {};

% 1
classes1_sorted = classes1(idxs);
varargout{end+1} = ypoll_get_it(codes_sorted, classes1_sorted, class_labels);

if flag_2
    classes2_sorted = classes2(idxs);
    varargout{end+1} = ypoll_get_it(codes_sorted, classes2_sorted, class_labels);
end;

% Does the actual work, except for calling data_sort_by_colony()
function ypoll = ypoll_get_it(colony_codes, classes, class_labels)

no_colonies = length(intersect(colony_codes, colony_codes));

ypoll = ypoll_new();
ypoll.class_labels = class_labels;
ypoll.classes = zeros(no_colonies, 1);
ypoll.maxpercs = zeros(no_colonies, 1);
ypoll.colony_codes = cell(no_colonies, 1);

no = length(colony_codes);
nc = length(ypoll.class_labels);
colony_save = '!@($*&';
cnt_colony = 0;
flag_reset_pool = 1;
for i = 1:(no+1)
    if i < no+1
        code_now = colony_codes{i};
    end;
    
    if i == no+1 || ~strcmp(code_now, colony_save)
        if i > 1
            cnt_colony = cnt_colony+1;

            ypoll.colony_codes{cnt_colony} = colony_save;

            % the pool
            [val, idx] = max(votes);
            ypoll.maxpercs(cnt_colony) = val/sum(votes);
            ypoll.maxvotes(cnt_colony) = val;
            ypoll.classes(cnt_colony) = idx-1;
        end;

        if i == no+1
            break;
        end;
        flag_reset_pool = 1;
    end;

    if flag_reset_pool
        flag_reset_pool = 0;
        colony_save = code_now;
        votes = zeros(1, nc);
    end;

    idx_temp = classes(i)+1;
    votes(idx_temp) = votes(idx_temp)+1;
end;

% Copyright 2010 Julio Trevisan, Plamen P. Angelov & Francis L. Martin.
% e-mailing author: j.trevisan@lancaster.ac.uk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% A copy of the GNU General Public License is shipped along with this
% program (filename: "COPYING").  For an online version of the license,
% see <http://www.gnu.org/licenses/>.
